import matplotlib.pyplot as plt
import numpy as np
from astropy import units as u
from synphot import SourceSpectrum, BaseUnitlessSpectrum
from synphot.models import BlackBodyNorm1D, Empirical1D, GaussianFlux1D
np.random.seed(1234)  # For reproducibility
# Create the smooth continuum that is a 5000 K blackbody.
bb = SourceSpectrum(BlackBodyNorm1D, temperature=5000)
# Then, add random noise to it. Since synphot spectrum object cannot
# be multiplied with scalar array, this has to be done indirectly by
# applying the noise as a unitless spectrum.
wave = np.arange(100, 30001, 10)
nse = 1 + np.random.normal(size=wave.size, scale=0.02)
sp_nse = BaseUnitlessSpectrum(Empirical1D, points=wave, lookup_table=nse)
bb_noisy = bb * sp_nse
# Apply emission and absorption lines to the noisy continuum.
tf_unit = u.erg / (u.cm**2 * u.s)
g_em = SourceSpectrum(
    GaussianFlux1D, total_flux=2.65e-14*tf_unit, mean=15000, fwhm=500)
g_ab = SourceSpectrum(
    GaussianFlux1D, total_flux=6.62e-14*tf_unit, mean=4500, fwhm=100)
sp = bb_noisy + g_em - g_ab
# Divide the noisy spectrum with lines with the original smooth continuum
# to obtain the continuum-normalized spectrum.
ratio = sp / bb
with np.errstate(invalid='ignore'):
    ratio.plot(left=2500, right=17000,
               title='Continuum-normalized spectrum')
plt.axhline(1, ls='--', color='k')