import os
import matplotlib.pyplot as plt
from astropy.utils.data import get_pkg_data_filename
from synphot import SpectralElement
from synphot.filter_parameterization import filter_to_fft, filter_from_fft
filename = get_pkg_data_filename(
    os.path.join('data', 'hst_acs_hrc_f555w.fits'),
    package='synphot.tests')
bp = SpectralElement.from_file(filename)
fit_result = filter_to_fft(bp)
reconstructed_bp = filter_from_fft(*fit_result)
w = bp.waveset
plt.plot(w, bp(w), 'b-', label='Original')
plt.plot(w, reconstructed_bp(w), 'r--', label='Reconstructed')
plt.xlim(3500, 8000)
plt.xlabel('Wavelength (Angstrom)')
plt.ylabel('Throughput')
plt.title('HST ACS/HRC F555W')
plt.legend(loc='upper right', numpoints=1)