import matplotlib.pyplot as plt
from synphot import SourceSpectrum
from synphot.models import BlackBodyNorm1D
fig, ax = plt.subplots(3, sharex=True)
# Create a source at rest wavelength and sample it because it will
# be modified in-place below
sp_rest = SourceSpectrum(BlackBodyNorm1D, temperature=5000)
wave = range(2500, 25000, 10)
flux = sp_rest(wave)
# Redshift the original source as a new spectrum
sp_z1 = SourceSpectrum(sp_rest.model, z=0.1)
ax[0].plot(wave, flux, 'b--', wave, sp_z1(wave), 'r')
# Redshift the original source in-place
sp_rest.z = 0.1
ax[1].plot(wave, flux, 'b--', wave, sp_rest(wave), 'r')
# Create a redshifted source from scratch
sp_z2 = SourceSpectrum(BlackBodyNorm1D, temperature=5000, z=0.1)
ax[2].plot(wave, flux, 'b--', wave, sp_z2(wave), 'r')
# Extra plot commands
ax[2].set_xlim(2500, 25000)
ax[2].set_xlabel('Wavelength (Angstrom)')
ax[1].set_ylabel('Flux (PHOTLAM)')
ax[0].legend(['z=0', 'z=0.1'], loc='upper right')