import os
import matplotlib.pyplot as plt
from astropy.utils.data import get_pkg_data_filename
from synphot import Observation, SourceSpectrum, SpectralElement, units
from synphot.models import BlackBodyNorm1D
# Construct blackbody source
sp = SourceSpectrum(BlackBodyNorm1D, temperature=5000)
# Simulate an instrument bandpass with custom binning
bp = SpectralElement.from_file(get_pkg_data_filename(
    os.path.join('data', 'hst_acs_hrc_f555w.fits'),
    package='synphot.tests'))
binset = range(1000, 11001)
# Build the observation and get binned flux in count
obs = Observation(sp, bp, binset=binset)
area = 45238.93416 * units.AREA  # HST
binflux = obs.sample_binned(flux_unit='count', area=area)
# Sample the "native" flux for comparison
flux = obs(obs.binset, flux_unit='count', area=area)
# Plot with zoom to see native vs binned
plt.plot(obs.binset, flux, 'bx-', label='native')
plt.plot(obs.binset, binflux, 'g-', drawstyle='steps-mid', label='binned')
plt.xlim(5342, 5372)
plt.ylim(5.598, 5.62)
plt.xlabel('Wavelength (Angstrom)')
plt.ylabel('Flux (count)')
plt.title('bb(5000) * acs,hrc,f555w')
plt.legend(loc='lower right', numpoints=1)